<?php
/**
 * Base class for productholder pages.
 *
 * Most children will extend it only to keep separate relations between product
 * categories but may also extend $db and getCMSFields().
 *
 */
class ProductList extends Page {
    static $db = array();

    /**
     * Sets the the value for DataObjectManager/ComplexTableField to use as
     * $sourceClass parameter.
     *
     * Must be set in each child class to get unique relationships and needs to
     * match the source class of relationship set in static $many_many array.
     * This setup keeps getCMSFields from having to be set in each child when
     * the only change would be $sourceClass.
     *
     * In testing $many_many would not only accept direct string for value and
     * cause an error when this variable was called in it's place.
     *
     * @var String
     */
    protected $dataObjectSourceClass = 'ProductObject';

    static $many_many = array(
    'Products' => 'ProductObject',
    );

    static $icon = "themes/blackcandy/images/treeicons/productlist";

    /**
     * Used to tell if a user can create pages of this type.
     *
     * Since this page type is intended to contain common elements for child
     * pages and shoulden't be used to create pages for the site and should always
     * return false. Child page types will have to overload it and return true
     * or else they won't be available in the CMS.
     *
     * @return TRUE/FALSE
     */
    function canCreate()
    {
        return FALSE;
    }

    /**
     * Extends standard FieldSets with DataObjectManager to manage Products
     * relation.
     * $dataObjectSourceClass lets children easily change to fit their relation
     * when no extra fields are needed without having to duplicate the method.
     *
     * @return FieldSet
     */
    function getCMSFields() {
        $fields = parent::getCMSFields();
        $productfields = new ManyManyDataObjectManager(
            $this,
            'Products',
            // Set at top of class and in sub-classes, see comments above.
            $this->dataObjectSourceClass,
            array(
            'code' => 'Code',
            'name' => 'Name',
            'description' => 'Description',
            ),
            'getCMSFields_forPopup'
        );
        $productfields->setAddTitle('A Product');
        $fields->removeFieldfromTab('Root.Content.Main', 'Content');
        $fields->addFieldToTab('Root.Content.Main', $productfields);
        return $fields;
    }
}
class ProductList_Controller extends Page_Controller {

}
?>
