<?php
/**
 * Base class for Product DataObjects.
 *
 * Sets up standard $db fields, default data relation, and CMSFields method.
 * Child classes will usualy only need to modify $belongs_many_many to allow
 * separate relations between product categories.
 * If extra $db fields are needed then getCMSFields_forPopup() will need to be
 * extended as well.
 *
 * @author Joshua Lewis
 *
 *
 * @todo research $belongs_many_many and what key and value each do.
 * @todo test and add product photo, MSDS, and Data Sheet, to $db.
 * @todo debug adding file fields to getCMSFields_forPopup()
 * @todo see about grouping checkboxes.
 * @todo research adding icons with the checkboxes in the popup
 * @todo change $db['description'] to wysiwyg field in popup
 */
class ProductObject extends DataObject {
    static $db = array (
    'name' => 'Text',
    'code' => 'Text',
    'description' => 'Text',
    'voc' => 'Boolean',
    'bodyshop' => 'Boolean',
    'phosphate' => 'Boolean',
    'npe' => 'Boolean',
    );

    /**
     * Child pages of this class will need to add thier own value.
     *
     * @var Array sets details for this side of many_many relations
     */
    static $belongs_many_many = array(
    'ProductLists' => 'ProductList'
    );

    /**
     * Called in place of the object's description field. Returns the contents
     * in different ways depending on parameters used.
     *
     * Default behavior is to return a shortened version when no parameters are
     * passed. This is because that version is required in the DataObjectManager
     * and I haven't found a way to call a parameter there. Any custom value
     * passed will cause the fields contents to be returned un-modified.
     *
     * @param string $display
     * @return string
     */
    public function description($display = 'short') {
        if ($display == 'short') {
            $limit = 35;
            $description = trim($this->description);
            if (strlen($description) > $limit) {
                $shortdescription = substr($description, 0, $limit) . '...';
            } else {
                $shortdescription = $description;
            }
            return $shortdescription;
        } else {
            return $this->description;
        }
    }

    function getCMSFields_forPopup() {
        $fields = new FieldSet();
        $fields->push( new TextField('code', 'Product Code'));
        $fields->push( new TextField('name', 'Product Name'));
        $fields->push( new TextareaField('description', 'Description'));
        $fields->push( new CheckboxField(
            $name = "voc",
            $title = "VOC Compliant"
        ));
        $fields->push( new CheckboxField(
            $name = "bodyshop",
            $title = "Bodyshop Safe"
        ));
        $fields->push( new CheckboxField(
            $name = "phosphate",
            $title = "Phosphate Free"
        ));
        $fields->push( new CheckboxField(
            $name = "npe",
            $title = "NPE Free"
        ));
        return $fields;
    }
}

?>
